@@ -36,7 +36,6 @@ void IdentityTester::initTestCase()
     QStandardPaths::setTestModeEnabled(true);
 }
 
-
 void IdentityTester::test_NullIdentity()
 {
     IdentityManager manager;
@@ -49,7 +48,7 @@ void IdentityTester::test_Aliases()
 
     // It is picking up identities from older tests somethimes, so cleanup
     while (manager.identities().size() > 1) {
-        manager.removeIdentity(manager.identities().first());
+        manager.removeIdentity(manager.identities().at(0));
         manager.commit();
     }
 
@@ -74,7 +73,7 @@ void IdentityTester::test_Aliases()
     manager.commit();
 
     // Remove the first identity, which we couldn't remove above
-    manager.removeIdentity(manager.identities().first());
+    manager.removeIdentity(manager.identities().at(0));
     manager.commit();
 
     QCOMPARE(manager.allEmails().size(), 4);
